package de.qsqs.mocktest;


import org.jmock.Expectations;
import org.jmock.Mockery;
import org.junit.Test;
import static org.junit.Assert.assertSame;

public class PublisherTest {
	
	
    Mockery context = new Mockery();
    
    @Test 
    public void oneSubscriberReceivesAMessage() {
        // set up - Erstellen des Mocks
        final Subscriber subscriber = context.mock(Subscriber.class);
        
        Publisher publisher = new Publisher();
        publisher.add(subscriber);
        
        final String message = "message";
        
        // expectations
        // Wird einmal geprueft, ob das Mock Objekt die Nachricht erhalten hat
        // Erwartet das receive() noch einam aufgerufen wird
        context.checking(new Expectations() {{
            one (subscriber).receive(message);
        }});
       
        // execute
        // Alle Subscriber werden ueber die neue Nachricht informiert
        publisher.publish(message);
        
        // wurde receive() einmal ausgefuehrt? (In diesem Fall ueber publisher.publish(message);)
        context.assertIsSatisfied();

        // Wird geprueft, ob auch die richtige Nachricht angekommen ist
        assertSame(message, publisher.getString());
    }
}